@@ -70,7 +70,7 @@ sub as_string {
     return join('/', @a) . ", " .
       '"' . $self->title . '"' . ", " .
       $self->year . ", " .
-      $self->OurPrice . ", " .
+      $self->_best_effort_price() . ", " .
       $self->ASIN;
 }
 
